<?php

namespace App\Controllers;

use App\Models\Users_m;
use App\Models\Entities_m;

use \Hermawan\DataTables\DataTable;

class Users extends BaseController
{
    public function index()
    {
        $entities = new Entities_m();
        $data['entities']  = $entities->table('sss_tbl_entities')->select("sss_ent_id,sss_ent_name")->where('sss_ent_status', 1)->get()->getResult();
        $data['pageTitle'] = 'Manage Users';
        return view('manageUser', $data);
    }

    public function getuser()
    {
        $db = db_connect();
        $builder = $db->table('sss_tbl_users')
                      ->select("sss_user_id, sss_user_fname, sss_tbl_entities.sss_ent_name,sss_user_role,sss_user_status,")
                      ->join('sss_tbl_entities', 'sss_tbl_entities.sss_ent_id = sss_tbl_users.sss_ent_id');

        return DataTable::of($builder)
            ->edit('sss_user_status', function ($row) {
                $btnStatus = $row->sss_user_status == 1 ? 'btn-success' : 'btn-secondary';
                $status = ($row->sss_user_status == 1) ? "Active" : "Inactive";
                return '<span type="button" class="btn btn-sm ' . $btnStatus . ' status_checks" data=' . $row->sss_user_id . '>' . $status . '</span>';
            })
            ->add('action', function ($userid) {
                return '<a class="btn btn-primary btn-sm" onclick="edit_user(' . $userid->sss_user_id . ')"><i class="fa fa-edit"></i></a> | <a class="btn btn-danger btn-sm" onclick="delete_user(' . $userid->sss_user_id . ')"><i class="fa fa-trash"></i></a>';
            }, 'last')
            ->hide('sss_user_id')
            ->toJson();
    }

    public function insert_user()
    {
        $validation = \Config\Services::validation();
        $this->validate([
            'ent_id' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please Select Entity',
                ]
            ],
            'sss_user_fname' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter First Name',
                ]
            ],
            'sss_user_lname' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Last name'
                ]
            ],
            'sss_user_email' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Email'
                ]
            ],
            'sss_user_password' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter password'
                ]
            ],
            'sss_user_designation' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Select Designation'
                ]
            ],
            'sss_user_mob' => [
                'rules' => 'required|is_unique[sss_tbl_users.sss_user_mob]',
                'errors' => [
                    'required' => 'Please enter Mobile Number',
                    'is_unique' => "Mobile Number already exist",
                ]
            ],
            'sss_user_addr' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please Enter Address'
                ]
            ], 
            'sss_user_pincode' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please Enter PINCODE'
                ]
            ],
            'sss_user_role' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please Select Role'
                ]
            ],
        ]);
        if ($validation->run() == FALSE) {
            $errors = $validation->getErrors();
            echo json_encode(['code' => 0, 'error' => $errors]);
        } else {

            $insertuser = new Users_m();
            $data = [
                'sss_ent_id' => $this->request->getVar('ent_id'),
                'sss_user_fname' => $this->request->getVar('sss_user_fname'),
                'sss_user_lname' => $this->request->getVar('sss_user_lname'),
                'sss_user_email' => $this->request->getVar('sss_user_email'),
                'sss_user_password' => md5($this->request->getVar('sss_user_password')),
                'sss_user_unencrypt_password' => $this->request->getVar('sss_user_password'),
                'sss_user_designation' => $this->request->getVar('sss_user_designation'),
                'sss_user_mob' => $this->request->getVar('sss_user_mob'),
                'sss_user_addr' => $this->request->getVar('sss_user_addr'),
                'sss_user_pincode' => $this->request->getVar('sss_user_pincode'),
                'sss_user_role' => $this->request->getVar('sss_user_role'),
                'sss_user_status' => true,
                'sss_user_created_by' => 1,
                'sss_user_created_date' => date('Y-m-d')
            ];

            $isInserted = $insertuser->insert($data);
            if (!empty($isInserted)) {
                echo json_encode(array("status" => true, "message" => 'Bank Detail Inserted'));
            } else {
                echo json_encode(array("status" => false, "message" => 'Something error while inserting Bank Detail'));
            }
        }
    }

    public function user_edit($id)
    {
        $Users_m = new Users_m();
        $data = $Users_m->find($id);
        echo json_encode($data);
    }

    public function user_update()
    {
        $updaterecord = new Users_m();
        $id = $this->request->getVar('sss_user_id');
        $data = [
            'sss_ent_id' => $this->request->getVar('ent_id'),
            'sss_user_fname' => $this->request->getVar('sss_user_fname'),
            'sss_user_lname' => $this->request->getVar('sss_user_lname'),
            'sss_user_email' => $this->request->getVar('sss_user_email'),
            'sss_user_password' => md5($this->request->getVar('sss_user_password')),
            'sss_user_unencrypt_password' => $this->request->getVar('sss_user_password'),
            'sss_user_designation' => $this->request->getVar('sss_user_designation'),
            'sss_user_mob' => $this->request->getVar('sss_user_mob'),
            'sss_user_addr' => $this->request->getVar('sss_user_addr'),
            'sss_user_pincode' => $this->request->getVar('sss_user_pincode'),
            'sss_user_role' => $this->request->getVar('sss_user_role'),
            'sss_user_updated_by' => 1,
            'sss_user_updated_date' => date('Y-m-d')
        ];

        $isUpdated = $updaterecord->update($id, $data);
        if (!empty($isUpdated)) {
            echo json_encode(array("status" => true, "message" => 'Bank Detail Updated'));
        } else {
            echo json_encode(array("status" => false, "message" => 'Something error while updating Bank Detail'));
        }
    }

    public function user_delete($id)
    {
        $Users_m = new Users_m();
        $r = $Users_m->delete_by_id($id);
        echo json_encode(array("status" => TRUE, "message" => $r));
    }

    public function update_user_status()
    {
        $upadtestatus = new Users_m();
        $id = $this->request->getVar('sss_user_id');
        $data = [
            'sss_user_status' => $this->request->getVar('sss_user_status'),
        ];
        $upadtestatus->update($id, $data);
    }
}
