<?php

namespace App\Controllers;

use App\Models\Entities_m;
use App\Models\Bankdetails_m;
use App\Models\MonthsBalances_m;
use \Hermawan\DataTables\DataTable;

class BankDetails extends BaseController
{
    public function index()
    {
        $entities = new Entities_m();
        $data['entities']  = $entities->table('sss_tbl_entities')->select("sss_ent_id,sss_ent_name")->where('sss_ent_status', 1)->get()->getResult();
        if (session('logged_in') == true && session('logged_in') == 1) {
            $data['pageTitle'] = 'Manage Bank Details';
            return view('bankdetails_v', $data);
        } else {
            return view('login', $data);
        }
    }

    public function getbankdetail()
    {
        $db = db_connect();
        $builder = $db->table('sss_tbl_entity_bank_details')
            ->select("sss_ent_bank_id, sss_ent_bank_name, sss_ent_bank_acc_no, sss_tbl_entities.sss_ent_name,sss_ent_bank_acc_openingbal,sss_ent_bank_acc_status,")
            ->join('sss_tbl_entities', 'sss_tbl_entities.sss_ent_id = sss_tbl_entity_bank_details.sss_ent_id');

        return DataTable::of($builder)
            ->edit('sss_ent_bank_acc_status', function ($row) {
                $btnStatus = $row->sss_ent_bank_acc_status == 1 ? 'btn-success' : 'btn-secondary';
                $status = ($row->sss_ent_bank_acc_status == 1) ? "Active" : "Inactive";
                return '<span type="button" class="btn btn-sm ' . $btnStatus . ' status_checks" data=' . $row->sss_ent_bank_id . '>' . $status . '</span>';
            })
            ->add('action', function ($bankid) {
                return '<a class="btn btn-primary btn-sm" onclick="edit_bank(' . $bankid->sss_ent_bank_id . ')"><i class="fa fa-edit"></i></a> | <a class="btn btn-danger btn-sm" onclick="delete_bank(' . $bankid->sss_ent_bank_id . ')"><i class="fa fa-trash"></i></a>';
            }, 'last')
            ->hide('sss_ent_bank_id')
            ->toJson();
    }

    public function insert_bankdetail()
    {
        $validation = \Config\Services::validation();
        $this->validate([
            'ent_id' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please Select Entity',
                ]
            ],
            'sss_ent_bank_acc_name' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Bank Account Name',
                ]
            ],
            'sss_ent_bank_name' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter bank name'
                ]
            ],
            'sss_ent_bank_branch' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter branch name'
                ]
            ],
            'sss_ent_bank_acc_no' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Account Number'
                ]
            ],
            'sss_ent_bank_acc_type' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Select Account Type'
                ]
            ],
            'sss_ent_bank_acc_ifsc' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter IFSC Code'
                ]
            ],
            'sss_ent_bank_acc_openingbal' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Opening Balance'
                ]
            ],
            'sss_ent_bank_isDefault' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Let us know these your default Account or not'
                ]
            ]
        ]);
        if ($validation->run() == FALSE) {
            $errors = $validation->getErrors();
            echo json_encode(['code' => 0, 'error' => $errors]);
        } else {

            $insertbank = new Bankdetails_m();
            $data = [
                'sss_ent_id' => $this->request->getVar('ent_id'),
                'sss_ent_bank_acc_name' => $this->request->getVar('sss_ent_bank_acc_name'),
                'sss_ent_bank_name' => $this->request->getVar('sss_ent_bank_name'),
                'sss_ent_bank_branch' => $this->request->getVar('sss_ent_bank_branch'),
                'sss_ent_bank_acc_no' => $this->request->getVar('sss_ent_bank_acc_no'),
                'sss_ent_bank_acc_type' => $this->request->getVar('sss_ent_bank_acc_type'),
                'sss_ent_bank_acc_ifsc' => $this->request->getVar('sss_ent_bank_acc_ifsc'),
                'sss_ent_bank_acc_openingbal' => $this->request->getVar('sss_ent_bank_acc_openingbal'),
                'sss_ent_bank_isDefault' => $this->request->getVar('sss_ent_bank_isDefault'),
                'sss_ent_bank_acc_status' => true,
                'sss_ent_bank_created_by' => session('userid'),
                'sss_ent_bank_created_date' => date('Y-m-d')
            ];

            $isInserted = $insertbank->insert($data);
            if (!empty($isInserted)) {
                echo json_encode(array("status" => true, "message" => 'Bank Detail Inserted'));
            } else {
                echo json_encode(array("status" => false, "message" => 'Something error while inserting Bank Detail'));
            }
        }
    }

    public function bankdetail_edit($id)
    {
        $Bankdetails_m = new Bankdetails_m();
        $data = $Bankdetails_m->find($id);
        echo json_encode($data);
    }

    public function bankdetail_update()
    {
        $updaterecord = new Bankdetails_m();
        $id = $this->request->getVar('sss_ent_bank_id');
        $data = [
            'sss_ent_id' => $this->request->getVar('ent_id'),
            'sss_ent_bank_acc_name' => $this->request->getVar('sss_ent_bank_acc_name'),
            'sss_ent_bank_name' => $this->request->getVar('sss_ent_bank_name'),
            'sss_ent_bank_branch' => $this->request->getVar('sss_ent_bank_branch'),
            'sss_ent_bank_acc_no' => $this->request->getVar('sss_ent_bank_acc_no'),
            'sss_ent_bank_acc_type' => $this->request->getVar('sss_ent_bank_acc_type'),
            'sss_ent_bank_acc_ifsc' => $this->request->getVar('sss_ent_bank_acc_ifsc'),
            'sss_ent_bank_acc_openingbal' => $this->request->getVar('sss_ent_bank_acc_openingbal'),
            'sss_ent_bank_isDefault' => $this->request->getVar('sss_ent_bank_isDefault'),
            'sss_ent_bank_last_updated_by	' => session('userid'),
            'sss_ent_bank_updated_date' => date('Y-m-d')
        ];
        // echo "<pre>";print_r($data);exit;
        $isUpdated = $updaterecord->update($id, $data);
        if (!empty($isUpdated)) {
            echo json_encode(array("status" => true, "message" => 'Bank Detail Updated'));
        } else {
            echo json_encode(array("status" => false, "message" => 'Something error while updating Bank Detail'));
        }
    }

    public function bankdetail_delete($id)
    {
        $Bankdetails_m = new Bankdetails_m();
        $r = $Bankdetails_m->delete_by_id($id);
        echo json_encode(array("status" => TRUE, "message" => $r));
    }

    public function update_bankdetail_status()
    {
        $upadtestatus = new Bankdetails_m();
        $id = $this->request->getVar('sss_ent_bank_id');
        $data = [
            'sss_ent_bank_acc_status' => $this->request->getVar('sss_ent_bank_acc_status'),
        ];

        $upadtestatus->update($id, $data);
    }

    public function getBanksOpeningBal_Cron()
    {
        
        $bankdetailModel = new Bankdetails_m();
        $bankdetails = $bankdetailModel->findAll();
        
        $MonthsBalances_m = new MonthsBalances_m();
       
        
        $dateComps = date_parse(date('Y-m-d'));
        $year = $dateComps['year'];
        $month = $dateComps['month'];
        $balance_month = $month."-".$year;
        
        if(!empty($bankdetails))
        {
            foreach ($bankdetails as $bankdetail) {
           
            $balanceArray = [
                'bankid' => $bankdetail['sss_ent_bank_id'],
                'openingbal' => $bankdetail['sss_ent_bank_acc_openingbal'],
                'balancemonth' => $balance_month,
                'month'=> $month,
                'year' => $year,
                'createdate' => date('Y-m-d H:i:s')
            ];
            $MonthsBalances_m->insert($balanceArray);
        }
        
            
        }
        
        
    }
}
