<?php

namespace App\Controllers;

use App\Controllers\BaseController;
use App\Models\SacCode_m;
use App\Models\Entities_m;
use \Hermawan\DataTables\DataTable;

class SacCode extends BaseController
{
    public function index()
    {
        $entities = new Entities_m();
        $data['entities']  = $entities->table('sss_tbl_entities')->select("sss_ent_id,sss_ent_name")->where('sss_ent_status', 1)->get()->getResult();
        $data['pageTitle'] = 'Manage SAC Code';
        return view('saccode_v', $data);
    }

    public function getsaccodes()
    {
        $db = db_connect();
        $builder = $db->table('sss_tbl_sac_code')
                    ->select("sss_sac_code_id, sss_tbl_entities.sss_ent_name, sss_invoice_type, sss_sac_code, status")
                    ->join('sss_tbl_entities', 'sss_tbl_entities.sss_ent_id = sss_tbl_sac_code.sss_ent_id');

        return DataTable::of($builder)
            ->edit('status', function ($row) {
                $btnStatus = $row->status == 1 ? 'btn-success' : 'btn-secondary';
                $status = ($row->status == 1) ? "Active" : "Inactive";
                return '<span type="button" class="btn btn-sm ' . $btnStatus . ' status_checks" data=' . $row->sss_sac_code_id . '>' . $status . '</span>';
            })
            ->add('action', function ($saccodeid) {
                return '<a class="btn btn-primary btn-sm" onclick="edit_saccode(' . $saccodeid->sss_sac_code_id . ')"><i class="fa fa-edit"></i></a> | <a class="btn btn-danger btn-sm" onclick="delete_saccode(' . $saccodeid->sss_sac_code_id . ')"><i class="fa fa-trash"></i></a>';
            }, 'last')
            ->hide('sss_sac_code_id')
            ->toJson();
    }


    public function insert_saccode()
    {
        $validation = \Config\Services::validation();
        $this->validate([
            'sss_ent_id' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please select entity',
                ]
            ],
            'sss_invoice_type' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please select invoice type',
                ]
            ],
            'sss_sac_code' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please Enter SAC Code'
                ]
            ]
        ]);
        if ($validation->run() == FALSE) {
            $errors = $validation->getErrors();
            echo json_encode(['code' => 0, 'error' => $errors]);
        } else {
            unset($_POST['tablename']);
            $insertrecord = new SacCode_m();
            $data = [
                'sss_ent_id' => $this->request->getVar('sss_ent_id'),
                'sss_invoice_type' => $this->request->getVar('sss_invoice_type'),
                'sss_sac_code' => $this->request->getVar('sss_sac_code'),
                'status' => true,
                'sss_sac_code_created_by' => session('userid'),
                'sss_sac_code_created_date' => date('Y-m-d')
            ];
            $isInserted = $insertrecord->insert($data);
            if (!empty($isInserted)) {
                echo json_encode(array("status" => true, "message" => 'Record Inserted'));
            } else {
                echo json_encode(array("status" => false, "message" => 'Something error while inserting record'));
            }
        }
    }

    public function Sac_edit($id)
    {
        $SacCode_m = new SacCode_m();
        $data = $SacCode_m->find($id);
        echo json_encode($data);
    }

    public function Sac_update()
    {
        $updaterecord = new SacCode_m();
        $id = $this->request->getVar('id');
        $data = [
            'sss_ent_id' => $this->request->getVar('sss_ent_id'),
            'sss_invoice_type' => $this->request->getVar('sss_invoice_type'),
            'sss_sac_code' => $this->request->getVar('sss_sac_code'),
            // 'status' => true,
            'sss_sac_code_last_updated_by' => session('userid'),
            'sss_sac_code_updated_date' => date('Y-m-d')
        ];
        $isUpdated = $updaterecord->update($id, $data);
        if (!empty($isUpdated)) {
            echo json_encode(array("status" => true, "message" => 'Record Updated'));
        } else {
            echo json_encode(array("status" => false, "message" => 'Something error while updating record'));
        }
    }

    public function Sac_delete($id)
    {
        $SacCode_m = new SacCode_m();
        $r = $SacCode_m->delete_by_id($id);
        echo json_encode(array("status" => TRUE, "message" => $r));
    }

    public function update_sac_status()
    {
        $upadtestatus = new SacCode_m();
        $id = $this->request->getVar('id');
        $data = [
            'status' => $this->request->getVar('status'),
        ];
        $upadtestatus->update($id, $data);
    }
}
