<?php

namespace App\Controllers;

use App\Controllers\BaseController;
use App\Models\Vendor_m;
use \Hermawan\DataTables\DataTable;

class Vendors extends BaseController
{
    public function index()
    {
        $data['pageTitle'] = 'Manage Vendor Info.';
        return view('vendor_v', $data);
    }

    public function getVendors()
    {
        $db = db_connect();
        $builder = $db->table('tbl_vendors')
            ->select("sss_vendor_id , sss_vendor_name, sss_vendor_panno, sss_vendor_isTds, sss_vendor_status");
           

        return DataTable::of($builder)
            ->edit('sss_vendor_status', function ($row) {
                $btnStatus = $row->sss_vendor_status == 1 ? 'btn-success' : 'btn-secondary';
                $status = ($row->sss_vendor_status == 1) ? "Active" : "Inactive";
                return '<span type="button" class="btn btn-sm ' . $btnStatus . ' status_checks" data=' . $row->sss_vendor_id . '>' . $status . '</span>';
            })
            ->add('action', function ($vendorid) {
                return '<a class="btn btn-primary btn-sm" onclick="edit_vendor(' . $vendorid->sss_vendor_id . ')"><i class="fa fa-edit"></i></a> | <a class="btn btn-danger btn-sm" onclick="delete_vendor(' . $vendorid->sss_vendor_id . ')"><i class="fa fa-trash"></i></a>';
            }, 'last')
            ->hide('sss_vendor_id ')
            ->toJson();
    }


    public function insert_vendor()
    {
        $validation = \Config\Services::validation();
        $this->validate([

            // 'sss_vendor_panno' => [
            //     'rules' => 'required',
            //     'errors' => [
            //         'required' => 'Please Enter Vendor PAN No.',
            //     ]
            // ],
            'sss_vendor_name' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please Enter Vendor Name'
                ]
            ]
        ]);
        if ($validation->run() == FALSE) {
            $errors = $validation->getErrors();
            echo json_encode(['code' => 0, 'error' => $errors]);
        } else {

            $insertrecord = new Vendor_m();
            $data = [
                'sss_vendor_name' => $this->request->getVar('sss_vendor_name'),
                'sss_vendor_panno' => $this->request->getVar('sss_vendor_panno'),
                'sss_vendor_isTds' => $this->request->getVar('sss_vendor_isTds'),
                'sss_vendor_status' => true,
                'createdby' => session('userid'),
                'createdate' => date('Y-m-d')
            ];
            $isInserted = $insertrecord->insert($data);
            if (!empty($isInserted)) {
                echo json_encode(array("status" => true, "message" => 'Record Inserted'));
            } else {
                echo json_encode(array("status" => false, "message" => 'Something error while inserting record'));
            }
        }
    }

    public function vendor_edit($id)
    {
        $Vendor_m = new Vendor_m();
        $data = $Vendor_m->find($id);
        echo json_encode($data);
    }

    public function vendor_update()
    {
        $updaterecord = new Vendor_m();
        $id = $this->request->getVar('sss_vendor_id');
      
        $data = [
            'sss_vendor_name' => $this->request->getVar('sss_vendor_name'),
            'sss_vendor_panno' => $this->request->getVar('sss_vendor_panno'),
            'sss_vendor_isTds' => $this->request->getVar('sss_vendor_isTds'),
            'sss_vendor_status' => true,
            'updatedby' => session('userid'),
            'updatedate' => date('Y-m-d')
        ];
        $isUpdated = $updaterecord->update($id, $data);
        if (!empty($isUpdated)) {
            echo json_encode(array("status" => true, "message" => 'Record Updated'));
        } else {
            echo json_encode(array("status" => false, "message" => 'Something error while updating record'));
        }
    }

    public function vendor_delete($id)
    {
        $Vendor_m = new Vendor_m();
        $r = $Vendor_m->delete($id);
        echo json_encode(array("status" => TRUE, "message" => $r));
    }

    public function update_vendor_status()
    {
        $upadtestatus = new Vendor_m();
        $id = $this->request->getVar('id');
        $data = [
            'sss_vendor_status' => $this->request->getVar('status'),
        ];
        $upadtestatus->update($id, $data);
    }
}
