<?php

namespace App\Controllers;

use App\Models\Entities_m;
use \Hermawan\DataTables\DataTable;

class Entities extends BaseController
{
    public function index()
    {
        $data['pageTitle'] = 'Manage Entities';
        return view('manageEntities', $data);
    }

    public function BankDetails()
    {
        $data['pageTitle'] = 'Manage Bank Details';
        return view('bankdetails_v', $data);
    }

    public function getentities()
    {
        $db = db_connect();
        $builder = $db->table('sss_tbl_entities')->select("sss_ent_id, sss_ent_name, sss_ent_gst_no, sss_ent_pan_no, sss_ent_status");
        return DataTable::of($builder)
            ->edit('sss_ent_status', function ($row) {
                $btnStatus = $row->sss_ent_status == 1 ? 'btn-success' : 'btn-secondary';
                $status = ($row->sss_ent_status == 1) ? "Active" : "Inactive";
                return '<span type="button" class="btn btn-sm ' . $btnStatus . ' status_checks" data=' . $row->sss_ent_id . '>' . $status . '</span>';
            })
            ->add('action', function ($entityid) {
                return '<a class="btn btn-primary btn-sm" onclick="edit_entity(' . $entityid->sss_ent_id . ')"><i class="fa fa-edit"></i></a> | <a class="btn btn-danger btn-sm" onclick="delete_entity(' . $entityid->sss_ent_id . ')"><i class="fa fa-trash"></i></a>';
            }, 'last')
            ->hide('sss_ent_id')
            ->toJson();
    }

    public function insert_entity()
    {
        $validation = \Config\Services::validation();
        $this->validate([
            'sss_ent_name' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter entity name',
                ]
            ],
            'sss_ent_inv_initial' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter invoice initial',
                ]
            ],
            'sss_ent_gst_no' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter GST No.'
                ]
            ],
            'sss_ent_pan_no' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter PAN No.'
                ]
            ],
            'sss_ent_email' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Email.'
                ]
            ],
            // 'sss_ent_email' => [
            //     'rules' => 'required',
            //     'errors' => [
            //         'required' => 'Please enter Email.'
            //     ]
            // ]
        ]);
        if ($validation->run() == FALSE) {
            $errors = $validation->getErrors();
            echo json_encode(['code' => 0, 'error' => $errors]);
        } else {

            $insertrecord = new Entities_m();
            $data = [
                'sss_ent_name' => $this->request->getVar('sss_ent_name'),
                'sss_ent_inv_initial' => $this->request->getVar('sss_ent_inv_initial'),
                'sss_ent_gst_no' => $this->request->getVar('sss_ent_gst_no'),
                'sss_ent_pan_no' => $this->request->getVar('sss_ent_pan_no'),
                'sss_ent_uadhar' => $this->request->getVar('sss_ent_uadhar'),
                'sss_ent_email' => $this->request->getVar('sss_ent_email'),
                'sss_ent_status' => true,
                'sss_ent_created_by' => session('userid'),
                'sss_ent_created_date' => date('Y-m-d')
            ];

            $isInserted = $insertrecord->insert($data);
            if (!empty($isInserted)) {
                echo json_encode(array("status" => true, "message" => 'Entity Inserted'));
            } else {
                echo json_encode(array("status" => false, "message" => 'Something error while inserting entity'));
            }
        }
    }

    public function entity_edit($id)
    {
        $Entities_m = new Entities_m();
        $data = $Entities_m->find($id);
        echo json_encode($data);
    }

    public function entity_update()
    {
        $updaterecord = new Entities_m();
        $id = $this->request->getVar('sss_ent_id');
        $data = [
            'sss_ent_name' => $this->request->getVar('sss_ent_name'),
            'sss_ent_inv_initial' => $this->request->getVar('sss_ent_inv_initial'),
            'sss_ent_gst_no' => $this->request->getVar('sss_ent_gst_no'),
            'sss_ent_pan_no' => $this->request->getVar('sss_ent_pan_no'),
            'sss_ent_uadhar' => $this->request->getVar('sss_ent_uadhar'),
            'sss_ent_email' => $this->request->getVar('sss_ent_email'),
            'sss_ent_last_updated_by' => session('userid'),
            'sss_ent_updated_date' => date('Y-m-d')
        ];
        // echo $id;
        // echo "<pre>";print_r($data);exit;
        $isUpdated = $updaterecord->update($id, $data);
        if (!empty($isUpdated)) {
            echo json_encode(array("status" => true, "message" => 'Entity Updated'));
        } else {
            echo json_encode(array("status" => false, "message" => 'Something error while updating entity'));
        }
    }

    public function entity_delete($id)
    {
        $Entities_m = new Entities_m();
        $r = $Entities_m->delete_by_id($id);
        echo json_encode(array("status" => TRUE, "message" => $r));
    }

    public function update_entity_status()
    {
        $upadtestatus = new Entities_m();
        $id = $this->request->getVar('sss_ent_id');
        $data = [
            'sss_ent_status' => $this->request->getVar('sss_ent_status'),
        ];
        $upadtestatus->update($id, $data);
    }
}
