<?php

namespace Config;

// Create a new instance of our RouteCollection class.
$routes = Services::routes();

// Load the system's routing file first, so that the app and ENVIRONMENT
// can override as needed.
if (is_file(SYSTEMPATH . 'Config/Routes.php')) {
    require SYSTEMPATH . 'Config/Routes.php';
}

/*
 * --------------------------------------------------------------------
 * Router Setup
 * --------------------------------------------------------------------
 */
$routes->setDefaultNamespace('App\Controllers');
$routes->setDefaultController('Dashboard');
$routes->setDefaultMethod('index');
$routes->setTranslateURIDashes(false);
$routes->set404Override();
// The Auto Routing (Legacy) is very dangerous. It is easy to create vulnerable apps
// where controller filters or CSRF protection are bypassed.
// If you don't want to define all routes, please use the Auto Routing (Improved).
// Set `$autoRoutesImproved` to true in `app/Config/Feature.php` and set the following to true.
// $routes->setAutoRoute(false);

/*
 * --------------------------------------------------------------------
 * Route Definitions
 * --------------------------------------------------------------------
 */

// We get a performance increase by specifying the default
// route since we don't have to scan directories.

$routes->get('/', 'Login::index');
$routes->post('checklogin', 'Login::check');
$routes->get('logout', 'Login::logout');

$routes->get('/Dashboard', 'Dashboard::index');
$routes->get('/CreateInvoice', 'CreateInvoice::index');


// $routes->get('/DealDisbursalChart', 'DealDisbursalChart::index');
// $routes->get('/DealDetailsDraft', 'DealDetailsDraft::index');
$routes->get('/CreateBankBookEntry', 'CreateBankBookEntry::index');
$routes->get('getPurposedropdown/(:num)', 'CreateBankBookEntry::getPurpose/$1');


// $routes->get('/CreateClient', 'CreateClient::index');
// $routes->get('/CreateUser', 'CreateUser::index');
// $routes->get('/CreateEmployee', 'CreateEmployee::index');
// $routes->get('/CreateEntity', 'CreateEntity::index');

// $routes->get('/Bankdetails', 'Entities::BankDetails');

// Saccode routes....

$routes->get('/Saccode', 'SacCode::index');
$routes->post('insertsaccode', 'SacCode::insert_saccode');
$routes->get('get_saccodes', 'SacCode::getsaccodes');
$routes->get('editrecord/(:num)', 'SacCode::Sac_edit/$1');
$routes->post('updatesaccode', 'SacCode::Sac_update');
$routes->get('deleterecord/(:num)', 'SacCode::Sac_delete/$1');
$routes->get('updatedsacstatus/', 'SacCode::update_sac_status');


// entity routes
$routes->get('/Entities', 'Entities::index');
$routes->post('insertentity', 'Entities::insert_entity');
$routes->get('getAllentity', 'Entities::getentities');
$routes->get('editent/(:num)', 'Entities::entity_edit/$1');
$routes->post('updateentity', 'Entities::entity_update');
$routes->get('deleteentity/(:num)', 'Entities::entity_delete/$1');
$routes->get('updatedentstatus/', 'Entities::update_entity_status');

// bank routes
$routes->get('/Bankdetail', 'BankDetails::index');
$routes->post('insertbankdetail', 'BankDetails::insert_bankdetail');
$routes->get('getAllbankdetail', 'BankDetails::getbankdetail');
$routes->get('editbankdetail/(:num)', 'BankDetails::bankdetail_edit/$1');
$routes->post('updatebankdetail', 'BankDetails::bankdetail_update');
$routes->get('deletebankdetail/(:num)', 'BankDetails::bankdetail_delete/$1');
$routes->get('updatebankdetailstatus/', 'BankDetails::update_bankdetail_status');

// User routes
$routes->get('/Users', 'Users::index');
$routes->post('insertuser', 'Users::insert_user');
$routes->get('getAlluser', 'Users::getuser');
$routes->get('edituser/(:num)', 'Users::user_edit/$1');
$routes->post('updateuser', 'Users::user_update');
$routes->get('deleteuser/(:num)', 'Users::user_delete/$1');
$routes->get('updateuserstatus/', 'Users::update_user_status');

// employee routes
$routes->get('/Employees', 'Employees::index');
$routes->post('insertemp', 'Employees::insert_emp');
$routes->get('getAllemp', 'Employees::getemp');
$routes->get('editemp/(:num)', 'Employees::emp_edit/$1');
$routes->post('updateemp', 'Employees::emp_update');
$routes->get('deleteemp/(:num)', 'Employees::emp_delete/$1');
$routes->get('updateempstatus/', 'Employees::update_emp_status');

$routes->get('/Outcomes', 'Outcomes::index');
$routes->post('insertoutcome', 'Outcomes::insert_outcome');
$routes->get('getAlloutcome', 'Outcomes::getoutcome');
$routes->get('editoutcome/(:num)', 'Outcomes::outcome_edit/$1');
$routes->post('updateoutcome', 'Outcomes::outcome_update');
$routes->get('deleteoutcome/(:num)', 'Outcomes::outcome_delete/$1');
$routes->get('updateoutcomestatus/', 'Outcomes::update_outcome_status');

// client routes
$routes->get('/Clients', 'Clients::index');
$routes->post('insertclient', 'Clients::insert_client');
$routes->get('getAllclient', 'Clients::getclient');
$routes->get('editclient/(:num)', 'Clients::client_edit/$1');
$routes->post('updateclient', 'Clients::client_update');
$routes->get('deleteclient/(:num)', 'Clients::client_delete/$1');
$routes->get('updateclientstatus/', 'Clients::update_client_status');


// invoices
$routes->get('getsaccode/(:num)', 'CreateInvoice::getsaccode/$1');
$routes->get('getcx/(:num)', 'CreateInvoice::getclient/$1');
$routes->get('getbank/(:num)', 'CreateInvoice::getbankdetails/$1');
$routes->post('saveinvoice', 'CreateInvoice::insert_invoice');
$routes->get('invoicetable', 'CreateInvoice::ViewInvoice');
$routes->get('get_invoices', 'CreateInvoice::getinvoices');
$routes->get('editinvoice/(:num)', 'CreateInvoice::editInvoice/$1');
$routes->post('updateinvoice', 'CreateInvoice::update_invoice');
$routes->get('printInvoice/(:num)', 'CreateInvoice::print_Invoice/$1');


// payment received.
$routes->get('/PaymentReceived/(:num)', 'PaymentReceived::index/$1');
$routes->get('getpaymentdetails/(:num)', 'PaymentReceived::getPayment_details/$1');
$routes->post('insertpaymentdetail', 'PaymentReceived::insert_paymentdetail');
$routes->get('editpaymentdetail/(:num)', 'PaymentReceived::edit_paymentdetail/$1');
$routes->post('updatepaymentdetail', 'PaymentReceived::update_paymentdetail');
$routes->get('deletepaymentreceived/(:num)', 'PaymentReceived::delete_paymentdetail/$1');


// DDC received.
$routes->get('/DealDisbursalChart/(:num)', 'DealDisbursalChart::index/$1');
$routes->get('getddc/(:num)', 'DealDisbursalChart::get_ddc/$1');
$routes->post('insertddc', 'DealDisbursalChart::insert_ddc');
$routes->get('editddc/(:num)', 'DealDisbursalChart::edit_ddc/$1');
$routes->post('updateddc', 'DealDisbursalChart::update_ddc');
$routes->get('deleteddc/(:num)', 'DealDisbursalChart::delete_ddc/$1');

// ddd
$routes->get('/DealDetailsDraft/(:num)', 'DealDetailsDraft::index/$1');
$routes->get('getddd/(:num)', 'DealDetailsDraft::get_ddd/$1');
$routes->post('insertddd', 'DealDetailsDraft::insert_ddd');
$routes->get('editddd/(:num)', 'DealDetailsDraft::edit_ddd/$1');
$routes->post('updateddd', 'DealDetailsDraft::update_ddd');
$routes->get('deleteddd/(:num)', 'DealDetailsDraft::delete_ddd/$1');

//bank book

$routes->get('/BankBook', 'BankBook::index');
$routes->get('getAllbankbook', 'BankBook::getbankbookdetail');
$routes->get('deletebankbook/(:num)', 'BankBook::Bankbook_delete/$1');


// Vendors routes....
$routes->get('/Vendors', 'Vendors::index');
$routes->post('insertvendor', 'Vendors::insert_vendor');
$routes->get('get_vendor', 'Vendors::getVendors');
$routes->get('editvendorrecord/(:num)', 'Vendors::vendor_edit/$1');
$routes->post('updatevendor', 'Vendors::vendor_update');
$routes->get('deletevendorrecord/(:num)', 'Vendors::vendor_delete/$1');
$routes->get('updatedvendorstatus/', 'Vendors::update_vendor_status');

// Vendors routes....
$routes->get('/Vendors-Purpose', 'VendorPurpose::index');
$routes->post('insertvp', 'VendorPurpose::insert_vp');
$routes->get('get_vp', 'VendorPurpose::getvp');
$routes->get('editvprecord/(:num)', 'VendorPurpose::vp_edit/$1');
$routes->post('updatevp', 'VendorPurpose::vp_update');
$routes->get('deletevprecord/(:num)', 'VendorPurpose::vp_delete/$1');
$routes->get('updatedvptatus/', 'VendorPurpose::update_vp_status');

/*
 * --------------------------------------------------------------------
 * Additional Routing
 * --------------------------------------------------------------------
 *
 * There will often be times that you need additional routing and you
 * need it to be able to override any defaults in this file. Environment
 * based routes is one such time. require() additional route files here
 * to make that happen.
 *
 * You will have access to the $routes object within that file without
 * needing to reload it.
 */
if (is_file(APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php')) {
    require APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php';
}
