<?php

namespace App\Controllers;
use App\Models\Employee_m;
use \Hermawan\DataTables\DataTable;

class Employees extends BaseController
{
    public function index()
    {
        $data['pageTitle'] = 'Manage Employee Info.';
        return view('manageEmployee',$data);
    }

    public function getemp()
    {
        $db = db_connect();
        $builder = $db->table('sss_tbl_emp')->select("sss_emp_id,sss_emp_code, sss_emp_fname, sss_emp_share, sss_emp_status");

        return DataTable::of($builder)
            ->edit('sss_emp_status', function ($row) {
                $btnStatus = $row->sss_emp_status == 1 ? 'btn-success' : 'btn-secondary';
                $status = ($row->sss_emp_status == 1) ? "Active" : "Inactive";
                return '<span type="button" class="btn btn-sm ' . $btnStatus . ' status_checks" data=' . $row->sss_emp_id . '>' . $status . '</span>';
            })
            ->add('action', function ($empid) {
                return '<a class="btn btn-primary btn-sm" onclick="edit_emp(' . $empid->sss_emp_id . ')"><i class="fa fa-edit"></i></a> | <a class="btn btn-danger btn-sm" onclick="delete_emp(' . $empid->sss_emp_id . ')"><i class="fa fa-trash"></i></a>';
            }, 'last')
            ->hide('sss_emp_id')
            ->toJson();
    }

    public function insert_emp()
    {
        $validation = \Config\Services::validation();
        $this->validate([
            'sss_emp_fname' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter First Name',
                ]
            ],
            'sss_emp_lname' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Last name'
                ]
            ],
            'sss_emp_email' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Email'
                ]
            ],
            'sss_emp_code' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Emp. Code'
                ]
            ],
            'sss_emp_share' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Emp. Share'
                ]
            ],
            'sss_emp_designation' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Select Designation'
                ]
            ],
            'sss_emp_mob' => [
                'rules' => 'required|is_unique[sss_tbl_emp.sss_emp_mob]',
                'errors' => [
                    'required' => 'Please enter Mobile Number',
                    'is_unique' => "Mobile Number is already exist",
                ]
            ],
            'sss_emp_addr' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please Enter Address'
                ]
            ],
            'sss_emp_pincode' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please Enter PINCODE'
                ]
            ],
        ]);
        if ($validation->run() == FALSE) {
            $errors = $validation->getErrors();
            echo json_encode(['code' => 0, 'error' => $errors]);
        } else {
            $insertemp = new Employee_m();
            $data = [
                'sss_emp_fname' => $this->request->getVar('sss_emp_fname'),
                'sss_emp_lname' => $this->request->getVar('sss_emp_lname'),
                'sss_emp_email' => $this->request->getVar('sss_emp_email'),
                'sss_emp_code' => $this->request->getVar('sss_emp_code'),
                'sss_emp_share' => $this->request->getVar('sss_emp_share'),
                'sss_emp_position' => $this->request->getVar('sss_emp_position'),
                'sss_emp_designation' => $this->request->getVar('sss_emp_designation'),
                'sss_emp_mob' => $this->request->getVar('sss_emp_mob'),
                'sss_emp_addr' => $this->request->getVar('sss_emp_addr'),
                'sss_emp_pincode' => $this->request->getVar('sss_emp_pincode'),
                'sss_emp_status' => true,
                'sss_emp_created_by' => session('userid'),
                'sss_emp_created_date' => date('Y-m-d')
            ];

            $isInserted = $insertemp->insert($data);
            if (!empty($isInserted)) {
                echo json_encode(array("status" => true, "message" => 'Employee Detail Inserted'));
            } else {
                echo json_encode(array("status" => false, "message" => 'Something error while inserting Employee Detail'));
            }
        }
    }

    public function emp_edit($id)
    {
        $Employee_m = new Employee_m();
        $data = $Employee_m->find($id);
        echo json_encode($data);
    }

    public function emp_update()
    {
        $updaterecord = new Employee_m();
        $id = $this->request->getVar('sss_emp_id');
        $data = [
            'sss_emp_fname' => $this->request->getVar('sss_emp_fname'),
            'sss_emp_lname' => $this->request->getVar('sss_emp_lname'),
            'sss_emp_email' => $this->request->getVar('sss_emp_email'),
            'sss_emp_code' => $this->request->getVar('sss_emp_code'),
            'sss_emp_share' => $this->request->getVar('sss_emp_share'),
            'sss_emp_position' => $this->request->getVar('sss_emp_position'),
            'sss_emp_designation' => $this->request->getVar('sss_emp_designation'),
            'sss_emp_mob' => $this->request->getVar('sss_emp_mob'),
            'sss_emp_addr' => $this->request->getVar('sss_emp_addr'),
            'sss_emp_pincode' => $this->request->getVar('sss_emp_pincode'),
            'sss_emp_updated_by' => 1,
            'sss_emp_updated_date' => date('Y-m-d')
        ];

        $isUpdated = $updaterecord->update($id, $data);
        if (!empty($isUpdated)) {
            echo json_encode(array("status" => true, "message" => 'Employee Detail Updated'));
        } else {
            echo json_encode(array("status" => false, "message" => 'Something error while updating Employee Detail'));
        }
    }

    public function emp_delete($id)
    {
        $Employee_m = new Employee_m();
        $r = $Employee_m->delete_by_id($id);
        echo json_encode(array("status" => TRUE, "message" => $r));
    }

    public function update_emp_status()
    {
        $upadtestatus = new Employee_m();
        $id = $this->request->getVar('sss_emp_id');
        $data = [
            'sss_emp_status' => $this->request->getVar('sss_emp_status'),
        ];
        $upadtestatus->update($id, $data);
    }
}
