<?php

namespace App\Controllers;

use App\Models\Client_m;
use App\Models\Entities_m;
use \Hermawan\DataTables\DataTable;

class Clients extends BaseController
{
    public function index()
    {
        $entities = new Entities_m();
        $data['entities']  = $entities->table('sss_tbl_entities')->select("sss_ent_id,sss_ent_name")->where('sss_ent_status', 1)->get()->getResult();
        if (session('logged_in') == true && session('logged_in') == 1) {
            $data['pageTitle'] = 'Manage Client';
            return view('manageClient', $data);
        } else {
            return view('login', $data);
        }
    }

    public function getclient()
    {
        $db = db_connect();
        $builder = $db->table('sss_tbl_client')->select("sss_client_id, sss_client_name, sss_client_gstno, sss_client_statecode, sss_client_status,");

        return DataTable::of($builder)
            ->edit('sss_client_status', function ($row) {
                $btnStatus = $row->sss_client_status == 1 ? 'btn-success' : 'btn-secondary';
                $status = ($row->sss_client_status == 1) ? "Active" : "Inactive";
                return '<span type="button" class="btn btn-sm ' . $btnStatus . ' status_checks" data=' . $row->sss_client_id . '>' . $status . '</span>';
            })
            ->add('action', function ($clientid) {
                return '<a class="btn btn-primary btn-sm" onclick="edit_client(' . $clientid->sss_client_id . ')"><i class="fa fa-edit"></i></a> | <a class="btn btn-danger btn-sm" onclick="delete_client(' . $clientid->sss_client_id . ')"><i class="fa fa-trash"></i></a>';
            }, 'last')
            ->hide('sss_client_id')
            ->toJson();
    }

    public function insert_client()
    {
        $validation = \Config\Services::validation();
        $this->validate([
            'sss_client_name' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Client Name',
                ]
            ],
            'sss_client_gstno' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter bank name'
                ]
            ],
            'sss_client_placeofservice' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter PLace of Service'
                ]
            ],
            'sss_client_statecode' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter State code'
                ]
            ],

        ]);
        if ($validation->run() == FALSE) {
            $errors = $validation->getErrors();
            echo json_encode(['code' => 0, 'error' => $errors]);
        } else {

            $insertclient = new Client_m();
            $data = [
                'sss_client_name' => $this->request->getVar('sss_client_name'),
                'sss_client_gstno' => $this->request->getVar('sss_client_gstno'),
                'sss_client_placeofservice' => $this->request->getVar('sss_client_placeofservice'),
                'sss_client_statecode' => $this->request->getVar('sss_client_statecode'),
                'sss_client_status' => true,
                'sss_client_created_by' => 1,
                'sss_client_updated_by' => date('Y-m-d')
            ];

            $isInserted = $insertclient->insert($data);
            if (!empty($isInserted)) {
                echo json_encode(array("status" => true, "message" => 'Client Detail Inserted'));
            } else {
                echo json_encode(array("status" => false, "message" => 'Something error while inserting Client Detail'));
            }
        }
    }

    public function client_edit($id)
    {
        $Client_m = new Client_m();
        $data = $Client_m->find($id);
        echo json_encode($data);
    }

    public function client_update()
    {
        $updaterecord = new Client_m();
        $id = $this->request->getVar('sss_client_id');
        $data = [
            'sss_client_name' => $this->request->getVar('sss_client_name'),
            'sss_client_gstno' => $this->request->getVar('sss_client_gstno'),
            'sss_client_placeofservice' => $this->request->getVar('sss_client_placeofservice'),
            'sss_client_statecode' => $this->request->getVar('sss_client_statecode'),
            'sss_client_updated_by' => 1,
            'sss_client_updated_date' => date('Y-m-d')
        ];

        $isUpdated = $updaterecord->update($id, $data);
        if (!empty($isUpdated)) {
            echo json_encode(array("status" => true, "message" => 'Client Detail Updated'));
        } else {
            echo json_encode(array("status" => false, "message" => 'Something error while updating Client Detail'));
        }
    }

    public function client_delete($id)
    {
        $Client_m = new Client_m();
        $r = $Client_m->delete_by_id($id);
        echo json_encode(array("status" => TRUE, "message" => $r));
    }

    public function update_client_status()
    {
        $upadtestatus = new Client_m();
        $id = $this->request->getVar('sss_client_id');
        $data = [
            'sss_client_status' => $this->request->getVar('sss_client_status'),
        ];

        $upadtestatus->update($id, $data);
    }
}
