<?php

namespace App\Controllers;

use App\Models\Outcomes_m;
use \Hermawan\DataTables\DataTable;

class Outcomes extends BaseController
{
    public function index()
    {
        $data['pageTitle'] = 'Manage Outcomes Info.';
        return view('manageoutcome', $data);
    }

    public function getoutcome()
    {
        $db = db_connect();
        $builder = $db->table('sss_tbl_outcomes')->select("sss_oc_id,sss_oc_name, sss_oc_share, sss_oc_type,sss_oc_status");

        return DataTable::of($builder)
            ->edit('sss_oc_status', function ($row) {
                $btnStatus = $row->sss_oc_status == 1 ? 'btn-success' : 'btn-secondary';
                $status = ($row->sss_oc_status == 1) ? "Active" : "Inactive";
                return '<span type="button" class="btn btn-sm ' . $btnStatus . ' status_checks" data=' . $row->sss_oc_id . '>' . $status . '</span>';
            })
            ->add('action', function ($ocid) {
                return '<a class="btn btn-primary btn-sm" onclick="edit_outcome(' . $ocid->sss_oc_id . ')"><i class="fa fa-edit"></i></a> | <a class="btn btn-danger btn-sm" onclick="delete_outcome(' . $ocid->sss_oc_id . ')"><i class="fa fa-trash"></i></a>';
            }, 'last')
            ->hide('sss_oc_id')
            ->toJson();
    }

    public function insert_outcome()
    {
        $validation = \Config\Services::validation();
        $this->validate([
            'sss_oc_name' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Title',
                ]
            ],
            'sss_oc_share' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter share'
                ]
            ]
        ]);
        if ($validation->run() == FALSE) {
            $errors = $validation->getErrors();
            echo json_encode(['code' => 0, 'error' => $errors]);
        } else {
            $insertemp = new Outcomes_m();
            $data = [
                'sss_oc_name' => $this->request->getVar('sss_oc_name'),
                'sss_oc_share' => $this->request->getVar('sss_oc_share'),
                'sss_oc_type' => $this->request->getVar('sss_oc_type'),
                'sss_oc_status' => true,
                'sss_oc_createdby' => 1,
                'sss_oc_createdate' => date('Y-m-d')
            ];

            $isInserted = $insertemp->insert($data);
            if (!empty($isInserted)) {
                echo json_encode(array("status" => true, "message" => 'Outcome Detail Inserted'));
            } else {
                echo json_encode(array("status" => false, "message" => 'Something error while inserting Outcome Detail'));
            }
        }
    }

    public function outcome_edit($id)
    {
        $Outcomes_m = new Outcomes_m();
        $data = $Outcomes_m->find($id);
        echo json_encode($data);
    }

    public function outcome_update()
    {
        $updaterecord = new Outcomes_m();
        $id = $this->request->getVar('sss_oc_id');
        $data = [
            'sss_oc_name' => $this->request->getVar('sss_oc_name'),
            'sss_oc_share' => $this->request->getVar('sss_oc_share'),
            'sss_oc_type' => $this->request->getVar('sss_oc_type'),
            'sss_emp_updated_by' => session('userid'),
            'sss_emp_updated_date' => date('Y-m-d')
        ];

        $isUpdated = $updaterecord->update($id, $data);
        if (!empty($isUpdated)) {
            echo json_encode(array("status" => true, "message" => 'Outcome Detail Updated'));
        } else {
            echo json_encode(array("status" => false, "message" => 'Something error while updating Outcome Detail'));
        }
    }

    public function outcome_delete($id)
    {
        $Outcomes_m = new Outcomes_m();
        $r = $Outcomes_m->delete_by_id($id);
        echo json_encode(array("status" => TRUE, "message" => $r));
    }

    public function update_outcome_status()
    {
        $upadtestatus = new Outcomes_m();
        $id = $this->request->getVar('sss_oc_id');
        $data = [
            'sss_oc_status' => $this->request->getVar('sss_oc_status'),
        ];
        $upadtestatus->update($id, $data);
    }
}
