<?php

namespace App\Controllers;

use App\Models\CreateInvoice_m;
use App\Models\PaymentReceived_m;
use \Hermawan\DataTables\DataTable;

class PaymentReceived extends BaseController
{
    public function index($invId)
    {
        $data['invId'] = $invId;
        $paymentlastid = new PaymentReceived_m();
        $data['lastbalamt'] = $paymentlastid->table('sss_tbl_paymentreceived')->select("sss_pr_tdsper,sss_pr_tdsamt,sss_pr_finalamt,sss_pr_balanceamt")
                        ->orderBy('sss_pr_id', 'DESC')
                        ->where('sss_inv_id', $invId)
                        ->get()->getRow();
        $invoices = new CreateInvoice_m();
        $data['invoice'] = $invoices->table('sss_tbl_invoices')->select("sss_inv_bill_no, sss_inv_bill_date,sss_tbl_client.sss_client_name,sss_inv_amt,sss_inv_desc,sss_inv_brief,sss_inv_sgst,sss_inv_cgst,sss_inv_igst,sss_inv_total_amt")
            ->join('sss_tbl_client', 'sss_tbl_client.sss_client_id = sss_tbl_invoices.sss_inv_client_id')
            ->where('sss_inv_id', $invId)
            ->get()->getRow();
        if ($data['invoice']->sss_inv_cgst != "0" || $data['invoice']->sss_inv_sgst != "0") {
            $totalgst = $data['invoice']->sss_inv_cgst + $data['invoice']->sss_inv_sgst;
            $data['totalgst'] = $totalgst;
        } else {
            $totalgst = $data['invoice']->sss_inv_igst;
            $data['totalgst'] = $totalgst;
        }
        $data['pageTitle'] = 'Payment Received';
        return view('paymentreceived_v', $data);
    }

    public function getPayment_details($invId)
    {
        $db = db_connect();
        $builder = $db->table('sss_tbl_paymentreceived')->select("sss_pr_id, sss_pr_reffno,sss_tbl_invoices.sss_inv_total_amt, sss_pr_amtreceived, sss_pr_balanceamt,sss_pr_datereceived,sss_pr_paymenttype")
            ->join('sss_tbl_invoices', 'sss_tbl_invoices.sss_inv_id = sss_tbl_paymentreceived.sss_inv_id')
            ->where('sss_tbl_paymentreceived.sss_inv_id', $invId)->orderBy('sss_pr_id', 'DESC');

        return DataTable::of($builder)
            ->add('action', function ($prid) {
                $btnStatus = $prid->sss_pr_balanceamt == 0 ? 'd-none d-lg-none d-md-none d-sm-none' : '';
                return '<a class="btn btn-seccondary btn-sm '.$btnStatus.'"   onclick="edit_paymentdetail(' . $prid->sss_pr_id . ')"><i class="fa fa-edit"></i></a> | <a class="btn btn-damger btn-sm" onclick="delete_paymentdetail(' . $prid->sss_pr_id . ')"><i class="fa fa-trash"></i></a> | <a class="btn btn-primary btn-sm mt-1" href="' . base_url() . '/DealDisbursalChart/'. $prid->sss_pr_id .'"> DealDisbursalChart </a>';
            }, 'last')
            ->hide('sss_pr_id')
            ->toJson();
    }

    public function insert_paymentdetail()
    {
        $validation = \Config\Services::validation();
        $this->validate([
            'sss_pr_tdsper' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Select TDS',
                ]
            ],
            'sss_pr_datereceived' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please select received date of payment',
                ]
            ],
            'sss_pr_paymentmode' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Select Payment Mode'
                ]
            ],
            'sss_pr_amtreceived' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Enter Amount which you receive',
                ]
            ]
        ]);
        if ($validation->run() == FALSE) {
            $errors = $validation->getErrors();
            echo json_encode(['code' => 0, 'error' => $errors]);
        } else {
            $lastidd = new PaymentReceived_m();
            $lastid = $lastidd->table('sss_tbl_paymentreceived')->select("sss_pr_id")->orderBy('sss_pr_id', 'DESC')->get()->getRow();
            $d = $lastid->sss_pr_id;
            $reffno = 'PR' . str_pad($d + 1, 5, '0', STR_PAD_LEFT);
            $insertrecord = new PaymentReceived_m();
            $data = [
                'sss_inv_id' => $this->request->getVar('sss_inv_id'),
                'sss_pr_tdsper' => $this->request->getVar('sss_pr_tdsper'),
                'sss_pr_tdsamt' => $this->request->getVar('sss_pr_tdsamt'),
                'sss_pr_reffno' => $reffno,
                'sss_pr_finalamt' =>  $this->request->getVar('sss_pr_finalamt'),
                'sss_pr_datereceived' => $this->request->getVar('sss_pr_datereceived'),
                'sss_pr_chequereceiveddate' => $this->request->getVar('sss_pr_chequereceiveddate'),
                'sss_pr_paymentmode' => $this->request->getVar('sss_pr_paymentmode'),
                'sss_pr_amtreceived' => $this->request->getVar('sss_pr_amtreceived'),
                'sss_pr_balanceamt' => $this->request->getVar('sss_pr_balanceamt'),
                'sss_pr_paymenttype' => $this->request->getVar('sss_pr_paymenttype'),
                'sss_sac_code_created_by' => session('userid'),
                'sss_pr_create_date' => date('Y-m-d')
            ];
            $isInserted = $insertrecord->insert($data);
            if (!empty($isInserted)) {
                echo json_encode(array("status" => true, "message" => 'Payment Details Inserted'));
            } else {
                echo json_encode(array("status" => false, "message" => 'Something error while inserting Payment Details'));
            }
        }
    }

    public function edit_paymentdetail($prid)
    {
        $editrecord = new PaymentReceived_m();
        $data = $editrecord->find($prid);
        echo json_encode($data);
    }

    public function update_paymentdetail()
    {
        $id = $this->request->getVar('sss_pr_id');
        $updaterecord = new PaymentReceived_m();
        $data = [
            'sss_inv_id' => $this->request->getVar('sss_inv_id'),
            'sss_pr_tdsper' => $this->request->getVar('sss_pr_tdsper'),
            'sss_pr_finalamt' =>  $this->request->getVar('sss_pr_finalamt'),
            'sss_pr_datereceived' => $this->request->getVar('sss_pr_datereceived'),
            'sss_pr_chequereceiveddate' => $this->request->getVar('sss_pr_chequereceiveddate'),
            'sss_pr_paymentmode' => $this->request->getVar('sss_pr_paymentmode'),
            'sss_pr_amtreceived' => $this->request->getVar('sss_pr_amtreceived'),
            'sss_pr_balanceamt' => $this->request->getVar('sss_pr_balanceamt'),
            'sss_pr_paymenttype' => $this->request->getVar('sss_pr_paymenttype'),
            'sss_sac_code_created_by' => session('userid'),
            'sss_pr_create_date' => date('Y-m-d')
        ];
        $isupdated = $updaterecord->update($id, $data);
        if (!empty($isupdated)) {
            echo json_encode(array("status" => true, "message" => 'Payment Details Updated'));
        } else {
            echo json_encode(array("status" => false, "message" => 'Something error while updating Payment Details'));
        }
    }

    public function delete_paymentdetail($prid)
    {
        $PaymentReceived_m = new PaymentReceived_m();
        $r = $PaymentReceived_m->delete_by_id($prid);
        echo json_encode(array("status" => TRUE, "message" => $r));
    }
}
