<?php

namespace App\Controllers;

use App\Controllers\BaseController;
use App\Models\Vendorpurpose_m;
use App\Models\Vendor_m;
use \Hermawan\DataTables\DataTable;

class VendorPurpose extends BaseController
{
    public function index()
    {
        $vendorslist = new Vendor_m();
        $data['vendorlist'] = $vendorslist->table('tbl_vendors')->select("sss_vendor_id, sss_vendor_name")->where('sss_vendor_status', 1)->get()->getResult();
  
        $data['pageTitle'] = 'Manage Vendor Purpose.';
        return view('vendor_purpose_v', $data);
    }

    public function getvp()
    {
        $db = db_connect();
        $builder = $db->table('sss_tbl_vendor_purpose')->select('sss_vp_id, tbl_vendors.sss_vendor_name, sss_vp_purpose, sss_vp_status')
            ->join('tbl_vendors','tbl_vendors.sss_vendor_id = sss_tbl_vendor_purpose.sss_v_id');

        return DataTable::of($builder)
            ->edit('sss_vp_status', function ($row) {
                $btnStatus = $row->sss_vp_status == 1 ? 'btn-success' : 'btn-secondary';
                $status = ($row->sss_vp_status == 1) ? "Active" : "Inactive";
                return '<span type="button" class="btn btn-sm ' . $btnStatus . ' status_checks" data=' . $row->sss_vp_id . '>' . $status . '</span>';
            })
            ->add('action', function ($vpid) {
                return '<a class="btn btn-primary btn-sm" onclick="edit_vp(' . $vpid->sss_vp_id . ')"><i class="fa fa-edit"></i></a> | <a class="btn btn-danger btn-sm" onclick="delete_vp(' . $vpid->sss_vp_id . ')"><i class="fa fa-trash"></i></a>';
            }, 'last')
            ->hide('sss_vp_id')
            ->toJson();
    }

    public function insert_vp()
    {
        $validation = \Config\Services::validation();
        $this->validate([
            'sss_v_id' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please Select Vendor',
                ]
            ],
            'sss_vp_purpose' => [
                'rules' => 'required',
                'errors' => [
                    'required' => 'Please enter Purpose'
                ]
            ]
        ]);
        if ($validation->run() == FALSE) {
            $errors = $validation->getErrors();
            echo json_encode(['code' => 0, 'error' => $errors]);
        } else {

            $insertrecord = new Vendorpurpose_m();
            $data = [
                'sss_v_id' => $this->request->getVar('sss_v_id'),
                'sss_vp_purpose' => $this->request->getVar('sss_vp_purpose'),
                'sss_vp_status' => true,
                'sss_vp_createdby' => session('userid'),
                'sss_vp_createdate' => date('Y-m-d')
            ];
            
            $isInserted = $insertrecord->insert($data);
            if (!empty($isInserted)) {
                echo json_encode(array("status" => true, "message" => 'Record Inserted'));
            } else {
                echo json_encode(array("status" => false, "message" => 'Something error while inserting record'));
            }
        }
    }

    public function vp_edit($id)
    {
        $Vendorpurpose_m = new Vendorpurpose_m();
        $data = $Vendorpurpose_m->find($id);
        echo json_encode($data);
    }

    public function vp_update()
    {
        $updaterecord = new Vendorpurpose_m();
        $id = $this->request->getVar('sss_vp_id');

        $data = [
            'sss_v_id' => $this->request->getVar('sss_v_id'),
            'sss_vp_purpose' => $this->request->getVar('sss_vp_purpose'),
            'sss_vp_status' => true,
            'sss_vp_updatedby' => session('userid'),
            'sss_vp_updatedate' => date('Y-m-d')
        ];
        $isUpdated = $updaterecord->update($id, $data);
        if (!empty($isUpdated)) {
            echo json_encode(array("status" => true, "message" => 'Record Updated'));
        } else {
            echo json_encode(array("status" => false, "message" => 'Something error while updating record'));
        }
    }

    public function vp_delete($id)
    {
        $Vendorpurpose_m = new Vendorpurpose_m();
        $r = $Vendorpurpose_m->delete_by_id($id);
        echo json_encode(array("status" => TRUE, "message" => $r));
    }

    public function update_vp_status()
    {
        $upadtestatus = new Vendorpurpose_m();
        $id = $this->request->getVar('sss_vp_id');
        $data = [
            'sss_vp_status' => $this->request->getVar('status'),
        ];
        $upadtestatus->update($id, $data);
    }

    // public function getPurpose($vendorid)
    // {
    //     $purposelist = new Vendorpurpose_m();
    //     $data = $purposelist->where('sss_v_id', $vendorid)->findAll();
    //     echo json_encode($data);
    // }
}
